==> lxqt-l10n-0.11.0.tar.xz: lxqt-l10n-0.11.0/lxqt-config/liblxqt-config-cursor/lxqt-config-cursor_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../../../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Definições do tema de cursor do LXQt</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Escolha o tema de cursor a utilizar (passe com o rato para testar). &lt;b&gt;Tem que reiniciar o LXQt a sessão após a alteração&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instalar novo tema...</translation>
    </message>
    <message>
        <source>&amp;Set Theme</source>
        <translation type="vanished">&amp;Definir tema</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Remover tema</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="vanished">Fe&amp;char</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="208"/>
        <source>XCurTheme error</source>
        <translation>Erro XCurTheme</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="209"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Não pode remover o tema ativo!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../../../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>O LXQt não encontrou quaisquer temas de cursor. Será utilizado o tema de cursor X11. O LXQt procurou nestes diretórios:</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Mostrar...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../../../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../../../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
</context>
</TS>

==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-config/liblxqt-config-cursor/lxqt-config-cursor_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>SelectWnd</name>
    <message>
        <location filename="../../../selectwnd.ui" line="14"/>
        <source>LXQt Mouse Theme Configuration</source>
        <translation>Definições do tema de cursor do LXQt</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="20"/>
        <source>Select the cursor theme you want to use (hover preview to test cursor). &lt;b&gt;LXQt session needs restart after this change&lt;/b&gt;:</source>
        <translation>Escolha o tema de cursor a utilizar (passe com o rato para testar). &lt;b&gt;Tem que reiniciar a sessão para aplicar esta alteração&lt;/b&gt;:</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="81"/>
        <source>&amp;Install New Theme...</source>
        <translation>&amp;Instalar novo tema...</translation>
    </message>
    <message>
        <source>&amp;Set Theme</source>
        <translation>&amp;Definir tema</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.ui" line="88"/>
        <source>&amp;Remove Theme</source>
        <translation>&amp;Remover tema</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Fe&amp;char</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="208"/>
        <source>XCurTheme error</source>
        <translation>Erro XCurTheme</translation>
    </message>
    <message>
        <location filename="../../../selectwnd.cpp" line="209"/>
        <source>You can&apos;t remove active theme!</source>
        <translation>Não pode remover o tema ativo!</translation>
    </message>
</context>
<context>
    <name>WarningLabel</name>
    <message>
        <location filename="../../../warninglabel.ui" line="14"/>
        <source>Form</source>
        <translation>Formulário</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="44"/>
        <source>LXQt could not find any cursor theme. The default X11 cursor theme will be used instead. LXQt looked in the following directories:</source>
        <translation>O LXQt não encontrou quaisquer temas de cursor. Será utilizado o tema de cursor X11. O LXQt procurou nestes diretórios:</translation>
    </message>
    <message>
        <location filename="../../../warninglabel.ui" line="54"/>
        <source>Show...</source>
        <translation>Mostrar...</translation>
    </message>
</context>
<context>
    <name>XCursorThemeModel</name>
    <message>
        <location filename="../../../thememodel.cpp" line="61"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../../../thememodel.cpp" line="62"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
</context>
</TS>
